@@ -14,11 +14,11 @@ if something goes wrong here, it's almost definitely my fault
 rather than a problem with the libftdi library.
 """
 
-__VERSION__ = "0.6"
+__VERSION__ = "0.7"
 __AUTHOR__ = "Ben Bass"
 
 
-__ALL__ = ['Driver', 'BitBangDriver', 'Bus', 'FtdiError',
+__ALL__ = ['Driver', 'Device', 'BitBangDevice', 'Bus', 'FtdiError',
            'ALL_OUTPUTS', 'ALL_INPUTS', 'BB_OUTPUT', 'BB_INPUT']
 
 from pylibftdi import _base, driver, util, bitbang
@@ -28,10 +28,20 @@ from pylibftdi import _base, driver, util, bitbang
 FtdiError = _base.FtdiError
 Bus = util.Bus
 Driver = driver.Driver
-BitBangDriver = bitbang.BitBangDriver
+Device = driver.Device
+BitBangDevice = bitbang.BitBangDevice
 
 ALL_OUTPUTS = bitbang.ALL_OUTPUTS
 ALL_INPUTS = bitbang.ALL_INPUTS
 BB_OUTPUT = bitbang.BB_OUTPUT
 BB_INPUT = bitbang.BB_INPUT
 
+
+# LEGACY SUPPORT
+
+class BitBangDriver(bitbang.BitBangDevice):
+    def __init__(self, direction=ALL_OUTPUTS):
+        import warnings
+        warnings.warn('change BitBangDriver reference to BitBangDevice',
+                      DeprecationWarning)
+        return BitBangDevice.__init__(self, direction=direction, lazy_open=True)
