@@ -8,15 +8,14 @@ pylibftdi: http://bitbucket.org/codedstructure/pylibftdi
 
 """
 
-from pylibftdi.driver import Driver
-from ctypes import byref 
+from pylibftdi.driver import Device, FtdiError
 
 ALL_OUTPUTS = 0xFF
 ALL_INPUTS = 0x00
 BB_OUTPUT = 1
 BB_INPUT = 0
 
-class BitBangDriver(Driver):
+class BitBangDevice(Device):
     """
     simple subclass to support bit-bang mode
 
@@ -26,17 +25,29 @@ class BitBangDriver(Driver):
      direction: 8 bit input(0)/output(1) direction control.
      port: 8 bit IO port, as defined by direction.
     """
-    def __init__(self, direction = ALL_OUTPUTS):
-        super(BitBangDriver, self).__init__(mode = 'b')
+    def __init__(self,
+                 device_id = None,
+                 direction = ALL_OUTPUTS,
+                 lazy_open = False):
+        # initialise the super-class, but don't open yet. We really want
+        # two-part initialisation here - set up all the instance variables
+        # here in the super class, then open it after having set more
+        # of our own variables.
+        super(BitBangDevice, self).__init__(device_id = device_id,
+                                            mode = 'b',
+                                            lazy_open = True)
         self.direction = direction
+        self._last_set_dir = None
         self._latch = 0
+        if not lazy_open:
+            self.open()
 
     def open(self):
         "open connection to a FTDI device"
         # in case someone sets the direction before we are open()ed,
         # we intercept this call...
-        super(BitBangDriver, self).open()
-        if self._direction:
+        super(BitBangDevice, self).open()
+        if self.direction != self._last_set_dir:
             self.direction = self._direction
         return self
 
@@ -53,10 +64,12 @@ class BitBangDriver(Driver):
 
     @direction.setter
     def direction(self, dir):
-        assert 0 <= dir <= 255, 'invalid direction bitmask'
+        if not (0 <= dir <= 255):
+            raise FtdiError("invalid direction bitmask")
         self._direction = dir
         if self.opened:
-            self.fdll.ftdi_set_bitmode(byref(self.ctx), dir, 0x01)
+            self.ftdi_fn.ftdi_set_bitmode(dir, 0x01)
+            self._last_set_dir = dir
 
 
     # port property - 8 bit read/write value
@@ -70,7 +83,7 @@ class BitBangDriver(Driver):
         # the coercion to bytearray here is to make this work
         # transparently between Python2 and Python3 - equivalent
         # of ord() for Python2, a time-wasting do-nothing on Python3
-        result = bytearray(super(BitBangDriver, self).read(1))[0]
+        result = bytearray(super(BitBangDevice, self).read(1))[0]
         # replace the 'output' bits with current value of _latch -
         # the last written value. This makes read-modify-write
         # operations (e.g. 'drv.port |= 0x10') work as expected
@@ -80,5 +93,5 @@ class BitBangDriver(Driver):
     @port.setter
     def port(self, value):
         self._latch = value
-        return super(BitBangDriver, self).write(chr(value))
+        return super(BitBangDevice, self).write(chr(value))
 
